==> v8.3.zip: ru_twords_ru_tw/bible/kt/abomination.md <==
# мерзость, мерзкий, омерзительный

## Определение:

Термин “мерзость” употребляется для обозначения чего-то противного, вызывающего отвращение.

* Египтяне считали еврейский народ “мерзостью”. Это значит, что египтянам было противно общаться с евреями или находиться рядом с ними.
* К тому, что Библия называет “мерзостью перед Яхве”, относятся: ложь, гордость, человеческие жертвоприношения, идолопоклонство, убийство и сексуальные грехи. Например, такие как прелюбодеяние (разврат) и гомосексуализм.
* Когда Иисус учил Своих учеников о последнем времени, Он ссылался на пророчество Даниила о “мерзости запустения”, происшедшей из непокорности Богу для осквернения места поклонения Ему.

## Варианты перевода:

* Термин “мерзость” можно также перевести как “что-то ненавистное Богу”, “отвратительная вещь”, “нечто противное”, “противный поступок” или “очень злой поступок”.
* В зависимости от контекста фразу “...есть мерзость перед...” можно перевести следующими способами: “...противно...”, “...совершенно неприемлемо...” или “...совершенно отвратительно...”.
* Выражение “мерзость запустения (осквернения)” можно перевести как “нечто противное, уничтожающее людей”. Или как “нечто отвратительное, несущее людям великое горе”.

(См. также: [прелюбодеяние](../kt/adultery.md), [осквернить](../other/desecrate.md), [опустошенный](../other/desolate.md), [идол](../kt/falsegod.md), [жертвоприношение](../other/sacrifice.md))

## Ссылки на библейский текст:

* [Ezra 9:1-2](rc://*/tn/help/ezr/09/01)
* [Быт. 46:33-34](rc://*/tn/help/gen/46/33)
* [Ис. 1:12-13](rc://*/tn/help/isa/01/12)
* [Мф. 24:15-18](rc://*/tn/help/mat/24/15)
* [Притч. 26:24-26](rc://*/tn/help/pro/26/24)

## Данные о слове:

* Номера Стронга: H887, H6292, H8251, H8262, H8263, H8441, G946

==> v9.2.zip: ru_twords_ru_tw/bible/kt/abomination.md <==
# мерзость, мерзкий, омерзительный

## Определение:

Термин “мерзость” употребляется для обозначения чего-то противного, вызывающего отвращение.
* Египтяне считали еврейский народ “мерзостью”. Это значит, что египтянам было противно общаться с евреями или находиться рядом с ними.
* К тому, что Библия называет “мерзостью перед Яхве”, относятся: ложь, гордость, человеческие жертвоприношения, идолопоклонство, убийство и сексуальные грехи. Например, такие как прелюбодеяние (разврат) и гомосексуализм.
* Когда Иисус учил Своих учеников о последнем времени, Он ссылался на пророчество Даниила о “мерзости запустения”, происшедшей из непокорности Богу для осквернения места поклонения Ему.


## Варианты перевода:

* Термин “мерзость” можно также перевести как “что-то ненавистное Богу”, “отвратительная вещь”, “нечто противное”, “противный поступок” или “очень злой поступок”.
* В зависимости от контекста фразу “...есть мерзость перед...” можно перевести следующими способами: “...противно...”, “...совершенно неприемлемо...” или “...совершенно отвратительно...”.
* Выражение “мерзость запустения (осквернения)” можно перевести как “нечто противное, уничтожающее людей”. Или как “нечто отвратительное, несущее людям великое горе”.


(См. также: [прелюбодеяние](../kt/adultery.md), [осквернить](../other/desecrate.md), [опустошенный](../other/desolate.md), [идол](../kt/falsegod.md), [жертвоприношение](../other/sacrifice.md))

## Ссылки на библейский текст:

* [Ezra 9:1-2](rc://ru/tn/help/ezr/09/01)
* [Быт. 46:33-34](rc://ru/tn/help/gen/46/33)
* [Ис. 1:12-13](rc://ru/tn/help/isa/01/12)
* [Мф. 24:15-18](rc://ru/tn/help/mat/24/15)
* [Притч. 26:24-26](rc://ru/tn/help/pro/26/24)

## Данные о слове:

* Номера Стронга: H887, H6292, H8251, H8262, H8263, H8441, G946
